@@ -2,13 +2,15 @@ import mock
 import sys
 
 import six
+from hypothesis import given
+from hypothesis.strategies import sampled_from
 
-from ...errors import OkonomiyakiError
+from okonomiyaki.errors import OkonomiyakiError
+from okonomiyaki.versions import RuntimeVersion
 
 from .. import EPDPlatform
 from ..epd_platform import (
-    _guess_epd_platform, EPD_PLATFORM_SHORT_NAMES, X86, X86_64, applies
-)
+    _guess_epd_platform, EPD_PLATFORM_SHORT_NAMES, X86, X86_64, applies)
 from ..legacy import _SUBDIR
 from .._platform import OSKind, FamilyKind, NameKind
 from .._arch import Arch
@@ -140,6 +142,25 @@ class TestEPDPlatform(unittest.TestCase):
         for epd_platform in epd_platforms:
             self.assertEqual(epd_platform.arch_bits, "64")
 
+    def test_epd_platform_from_string_with_runtime_version(self):
+        # given
+        version = RuntimeVersion.from_string('3.6.5+6')
+
+        # when/then
+        epd_platform = EPDPlatform.from_string('osx-64', version)
+        self.assertEqual(epd_platform.platform.release, '10.6')
+        epd_platform = EPDPlatform.from_string('win-64', version)
+        self.assertEqual(epd_platform.platform.release, '')
+
+        # given
+        version = RuntimeVersion.from_string('3.8.8+2')
+
+        # when/then
+        epd_platform = EPDPlatform.from_string('osx-64', version)
+        self.assertEqual(epd_platform.platform.release, '10.14')
+        epd_platform = EPDPlatform.from_string('win-64', version)
+        self.assertEqual(epd_platform.platform.release, '10')
+
     @mock_darwin
     @mock_machine_x86_64
     def test_from_running_python(self):
@@ -227,23 +248,62 @@ class TestEPDPlatform(unittest.TestCase):
         # Then
         self.assertEqual(str(epd_platform), s)
 
-    def test_pep425_tag(self):
+    @given(sampled_from((
+        ("rh5_x86", None, "linux_i686"),
+        ("rh5_x86_64", None, "linux_x86_64"),
+        ("osx_x86", None, "macosx_10_6_i386"),
+        ("osx_x86", '3.8.9+1', "macosx_10_14_i386"),
+        ("osx_x86_64", None, "macosx_10_6_x86_64"),
+        ("osx_x86_64", '3.8.9+1', "macosx_10_14_x86_64"),
+        ("win_x86", None, "win32"),
+        ("win_x86_64", None, "win_amd64"),
+        ("win_x86_64", '3.9.1', "win_amd64"))))
+    def test_pep425_tag(self, arguments):
         # Given
-        epd_string_to_pep425 = (
-            ("rh5_x86", "linux_i686"),
-            ("rh5_x86_64", "linux_x86_64"),
-            ("osx_x86", "macosx_10_6_i386"),
-            ("osx_x86_64", "macosx_10_6_x86_64"),
-            ("win_x86", "win32"),
-            ("win_x86_64", "win_amd64"),
-        )
+        platform_tag, version, expected = arguments
+        if version is not None:
+            runtime_version = RuntimeVersion.from_string(version)
+        else:
+            runtime_version = None
+        epd_platform = EPDPlatform.from_string(platform_tag, runtime_version)
 
         # When/Then
-        for epd_string, platform_tag in epd_string_to_pep425:
-            self.assertEqual(
-                EPDPlatform.from_string(epd_string).pep425_tag,
-                platform_tag,
-            )
+        self.assertEqual(epd_platform.pep425_tag, expected)
+
+    @given(sampled_from((
+        ('linux2', None, 'i686', 'linux_i686', 'cp36', 'gnu'),
+        ('linux2', 'RedHat_3', 'i386', 'linux_i386', 'cp27', 'gnu'),
+        ('linux2', 'RedHat_5', 'x86', 'linux_i686', 'cp27', 'gnu'),
+        ('linux2', 'RedHat_5', 'amd64', 'linux_x86_64', 'cp27', 'gnu'),
+        ('linux2', 'RedHat_6', 'amd64', 'linux_x86_64', 'cp36', 'gnu'),
+        ('linux2', 'RedHat_7', 'amd64', 'linux_x86_64', 'cp38', 'gnu'),
+        ('darwin', None, 'x86', 'osx_10_6_x86', 'cp27', 'darwin'),
+        ('darwin', None, 'amd64', 'osx_10_6_x86_64', 'cp27', 'darwin'),
+        ('darwin', None, 'amd64', 'osx_10_9_x86_64', 'cp36', 'darwin'),
+        ('darwin', None, 'amd64', 'osx_10_14_x86_64', 'cp38', 'darwin'),
+        ('win32', None, 'x86', 'win32', 'cp27', 'msvc2008'),
+        ('win32', None, 'amd64', 'win_amd64', 'cp27', 'msvc2008'),
+        ('win32', None, 'x86', 'win32', 'cp36', 'msvc2015'),
+        ('win32', None, 'amd64', 'win_amd64', 'cp36', 'msvc2015'),
+        ('win32', None, 'x86', 'win32', 'cp38', 'msvc2019'),
+        ('win32', None, 'amd64', 'win_amd64', 'cp38', 'msvc2019'),
+    )))
+    def test_from_spec_depend_data(self, arguments):
+        # when
+        epd_platform = EPDPlatform._from_spec_depend_data(*arguments)
+        platform, osdist, arch_name, platform_tag, python_version, platform_abi = arguments
+
+        # then
+        if '64' in arch_name:
+            self.assertEqual(epd_platform.arch, X86_64)
+        else:
+            self.assertEqual(epd_platform.arch, X86)
+        if 'linux' in platform:
+            self.assertIn('linux', epd_platform.pep425_tag)
+        elif 'win32' in platform:
+            self.assertIn('win', epd_platform.pep425_tag)
+        elif 'darwin' in platform:
+            self.assertIn('osx', epd_platform.pep425_tag)
 
 
 class TestEPDPlatformApplies(unittest.TestCase):
@@ -452,32 +512,6 @@ class TestGuessEPDPlatform(unittest.TestCase):
     def test_guess_solaris_unsupported(self):
         self.assertRaises(OkonomiyakiError, _guess_epd_platform)
 
-    def test_from_spec_depend_data(self):
-        # Given
-        examples = (
-            (("linux2", None, "x86"),
-             EPDPlatform.from_string("rh5-32"),),
-            (("linux2", "RedHat_3", "x86"),
-             EPDPlatform.from_string("rh3-32"),),
-            (("linux2", "RedHat_5", "x86"),
-             EPDPlatform.from_string("rh5-32"),),
-            (("linux2", "RedHat_5", "amd64"),
-             EPDPlatform.from_string("rh5-64"),),
-            (("darwin", None, "x86"),
-             EPDPlatform.from_string("osx-32"),),
-            (("darwin", None, "amd64"),
-             EPDPlatform.from_string("osx-64"),),
-            (("win32", None, "x86"),
-             EPDPlatform.from_string("win-32"),),
-            (("win32", None, "amd64"),
-             EPDPlatform.from_string("win-64"),),
-        )
-
-        # When/Then
-        for args, r_platform in examples:
-            platform = EPDPlatform._from_spec_depend_data(*args)
-            self.assertEqual(platform, r_platform)
-
     def test_from_epd_platform_string(self):
         # Given
         epd_platform_string = "rh5-32"
